=================
Smart Meter Texas
=================


.. image:: https://img.shields.io/pypi/v/smart_meter_texas.svg
        :target: https://pypi.python.org/pypi/smart_meter_texas

.. image:: https://img.shields.io/travis/grahamwetzler/smart-meter-texas.svg
        :target: https://travis-ci.com/grahamwetzler/smart-meter-texas


Package to asynchronously connect to and retrieve data from the unofficial Smart Meter Texas API using aiohttp.

Currently only obtaining the dashboard and current meter reading are implemented. There are serval other API endpoints that are not implemented in this package.


* Free software: MIT license


Install
--------
To install:

.. code-block:: bash

  $ pip install smart-meter-texas

Example
-------

Please see the examples for an idea of how to get started using the package.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
